==> owncloud-5.0.17.tar.bz2: owncloud/apps/calendar/l10n/es_AR.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Todavía no se guardaron en caché todos los calendarios",
"Everything seems to be completely cached" => "Parece que se guardó todo en el caché",
"No calendars found." => "No se encontraron calendarios.",
"No events found." => "No se encontraron eventos.",
"Wrong calendar" => "Calendario incorrecto",
"You do not have the permissions to edit this event." => "No tenés permisos suficientes para editar este evento.",
"The file contained either no events or all events are already saved in your calendar." => "El archivo no contiene eventos o ya existen en tu calendario.",
"events has been saved in the new calendar" => "Los eventos fueros guardados en el nuevo calendario",
"Import failed" => "Error al importar",
"events has been saved in your calendar" => "los eventos fueron guardados en tu calendario",
"New Timezone:" => "Nueva zona horaria:",
"Timezone changed" => "Zona horaria cambiada",
"Invalid request" => "Pedido no válido",
"Calendar" => "Calendario",
"Deletion failed" => "Error al borrar",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "usuario",
"group" => "grupo",
"Editable" => "Editable",
"Shareable" => "Se puede compartir",
"Deletable" => "Se puede borrar",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Domingo",
"Monday" => "Lunes",
"Tuesday" => "Martes",
"Wednesday" => "Miércoles",
"Thursday" => "Jueves",
"Friday" => "Viernes",
"Saturday" => "Sábado",
"Sun." => "dom.",
"Mon." => "lun.",
"Tue." => "mar.",
"Wed." => "miér.",
"Thu." => "jue.",
"Fri." => "vie.",
"Sat." => "sáb.",
"January" => "enero",
"February" => "febrero",
"March" => "marzo",
"April" => "abril",
"May" => "mayo",
"June" => "junio",
"July" => "julio",
"August" => "agosto",
"September" => "septiembre",
"October" => "octubre",
"November" => "noviembre",
"December" => "diciembre",
"Jan." => "ene.",
"Feb." => "feb.",
"Mar." => "mar.",
"Apr." => "abr.",
"May." => "may.",
"Jun." => "jun.",
"Jul." => "jul.",
"Aug." => "ago.",
"Sep." => "sep.",
"Oct." => "oct.",
"Nov." => "nov.",
"Dec." => "dic.",
"All day" => "Todo el día",
"New Calendar" => "Calendario nuevo",
"Missing or invalid fields" => "Campos faltantes o inválidos",
"Title" => "Título",
"From Date" => "Desde la fecha",
"From Time" => "Desde la hora",
"To Date" => "Hasta la fecha",
"To Time" => "Hasta la hora",
"The event ends before it starts" => "El evento termina antes de comiezar",
"There was a database fail" => "Se ha producido un error en la base de datos",
"Birthday" => "Cumpleaños",
"Business" => "Negocios",
"Call" => "Llamada",
"Clients" => "Clientes",
"Deliverer" => "Despachante",
"Holidays" => "Feriados",
"Ideas" => "Ideas",
"Journey" => "Viaje",
"Jubilee" => "Aniversario",
"Meeting" => "Reunión",
"Other" => "Otro",
"Personal" => "Personal",
"Projects" => "Proyectos",
"Questions" => "Preguntas",
"Work" => "Trabajo",
"by" => "por",
"unnamed" => "sin nombre",
"You do not have the permissions to update this calendar." => "No tenés permisos suficientes para actualizar este calendario.",
"You do not have the permissions to delete this calendar." => "No tenés permisos suficientes para eliminar este calendario.",
"You do not have the permissions to add to this calendar." => "No tenés permisos suficientes para añadir a este calendario.",
"You do not have the permissions to add events to this calendar." => "No tenés permisos suficientes para añadir eventos a este calendario.",
"You do not have the permissions to delete this event." => "No tenés permisos suficientes para eliminar este evento.",
"Busy" => "Ocupado",
"Public" => "Publico",
"Private" => "Privado",
"Confidential" => "Confidencial",
"Does not repeat" => "No se repite",
"Daily" => "Diariamente",
"Weekly" => "Semanalmente",
"Every Weekday" => "Días laborables",
"Bi-Weekly" => "Cada 2 semanas",
"Monthly" => "Mensualmente",
"Yearly" => "Anualmente",
"never" => "nunca",
"by occurrences" => "por ocurrencias",
"by date" => "por fecha",
"by monthday" => "por día del mes",
"by weekday" => "por día de la semana",
"events week of month" => "eventos de la semana dentro del mes",
"first" => "primer",
"second" => "segundo",
"third" => "tercer",
"fourth" => "cuarto",
"fifth" => "quinto",
"last" => "último",
"by events date" => "por fecha de los eventos",
"by yearday(s)" => "por día(s) del año",
"by weeknumber(s)" => "por número(s) de semana",
"by day and month" => "por día y mes",
"Date" => "Fecha",
"Cal." => "Cal.",
"Week" => "Semana",
"Month" => "Mes",
"List" => "Lista",
"Today" => "Hoy",
"Settings" => "Ajustes",
"Your calendars" => "Tus calendarios",
"CalDav Link" => "Enlace a CalDav",
"Share Calendar" => "Compartir calendario",
"Download" => "Descargar",
"Edit" => "Editar",
"Delete" => "Borrar",
"New calendar" => "Calendario nuevo",
"Edit calendar" => "Editar calendario",
"Displayname" => "Nombre",
"Active" => "Activo",
"Calendar color" => "Color del calendario",
"Save" => "Guardar",
"Submit" => "Guardar",
"Cancel" => "Cancelar",
"Edit an event" => "Editar un evento",
"Export" => "Exportar",
"Eventinfo" => "Información del evento",
"Repeating" => "Repetición",
"Alarm" => "Alarma",
"Attendees" => "Asistentes",
"Share" => "Compartir",
"Title of the Event" => "Título del evento",
"Category" => "Categoría",
"Separate categories with commas" => "Separar categorías con comas",
"Edit categories" => "Editar categorías",
"Access Class" => "Clase de acceso",
"All Day Event" => "Todo el día",
"From" => "Desde",
"To" => "Hasta",
"Advanced options" => "Opciones avanzadas",
"Location" => "Lugar",
"Location of the Event" => "Lugar del evento",
"Description" => "Descripción",
"Description of the Event" => "Descripción del evento",
"Repeat" => "Repetir",
"Advanced" => "Avanzado",
"Select weekdays" => "Seleccionar días de la semana",
"Select days" => "Seleccionar días",
"and the events day of year." => "y el día del año de los eventos.",
"and the events day of month." => "y el día del mes de los eventos.",
"Select months" => "Seleccionar meses",
"Select weeks" => "Seleccionar semanas",
"and the events week of year." => "y la semana del año de los eventos.",
"Interval" => "Intervalo",
"End" => "Fin",
"occurrences" => "ocurrencias:",
"create a new calendar" => "Crear un nuevo calendario",
"Import a calendar file" => "Importar un archivo de calendario",
"Please choose a calendar" => "Elegí un calendario",
"Name of new calendar" => "Nombre del nuevo calendario",
"Take an available name!" => "¡Elegí un nombre que esté disponible!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Ya existe un calendario con este nombre. Si seguís, se combinarán los calendarios.",
"Remove all events from the selected calendar" => "Remover todos los eventos del calendario seleccionado ",
"Import" => "Importar",
"Close Dialog" => "Cerrar diálogo",
"Create a new event" => "Crear un evento nuevo",
"Share with:" => "Compartir con:",
"Shared with" => "Compartir con",
"Unshare" => "Dejar de compartir",
"Nobody" => "Nadie",
"Shared via calendar" => "Compartido a través del calendario",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "Nota: Acciones sobre eventos compartidos a través del calendario, afectan el la compartición del calendario en su totalidad",
"View an event" => "Ver un evento",
"No categories selected" => "No hay categorías seleccionada",
"of" => "de",
"at" => "a las",
"General" => "General",
"Timezone" => "Zona horaria",
"Update timezone automatically" => "Actualizar zona horaria automáticamente",
"Time format" => "Formato de hora",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "La semana comienza el",
"Cache" => "Caché",
"Clear cache for repeating events" => "Limpiar caché de eventos recurrentes",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "Direcciones de sincronización de calendario CalDAV:",
"more info" => "más información",
"Primary address (Kontact et al)" => "Dirección principal (Kontact y semejantes)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Enlace(s) iCalendar de sólo lectura"
);

==> owncloud_7.0.11~dfsg.orig.tar.bz2: owncloud/apps/calendar/l10n/es_AR.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Todavía no se guardaron en caché todos los calendarios",
"Everything seems to be completely cached" => "Parece que se guardó todo en el caché",
"No calendars found." => "No se encontraron calendarios.",
"No events found." => "No se encontraron eventos.",
"Wrong calendar" => "Calendario incorrecto",
"You do not have the permissions to edit this event." => "No tenés permisos suficientes para editar este evento.",
"The file contained either no events or all events are already saved in your calendar." => "El archivo no contiene eventos o ya existen en tu calendario.",
"Import failed" => "Error al importar",
"New Timezone:" => "Nueva zona horaria:",
"Timezone changed" => "Zona horaria cambiada",
"Invalid request" => "Pedido no válido",
"Calendar" => "Calendario",
"Deletion failed" => "Error al borrar",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "grupo",
"can edit" => "podés editar",
"can share" => "puede compartir",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Domingo",
"Monday" => "Lunes",
"Tuesday" => "Martes",
"Wednesday" => "Miércoles",
"Thursday" => "Jueves",
"Friday" => "Viernes",
"Saturday" => "Sábado",
"Sun." => "dom.",
"Mon." => "lun.",
"Tue." => "mar.",
"Wed." => "miér.",
"Thu." => "jue.",
"Fri." => "vie.",
"Sat." => "sáb.",
"January" => "enero",
"February" => "febrero",
"March" => "marzo",
"April" => "abril",
"May" => "mayo",
"June" => "junio",
"July" => "julio",
"August" => "agosto",
"September" => "septiembre",
"October" => "octubre",
"November" => "noviembre",
"December" => "diciembre",
"Jan." => "ene.",
"Feb." => "feb.",
"Mar." => "mar.",
"Apr." => "abr.",
"May." => "may.",
"Jun." => "jun.",
"Jul." => "jul.",
"Aug." => "ago.",
"Sep." => "sep.",
"Oct." => "oct.",
"Nov." => "nov.",
"Dec." => "dic.",
"All day" => "Todo el día",
"New Calendar" => "Calendario nuevo",
"Missing or invalid fields" => "Campos faltantes o inválidos",
"Title" => "Título",
"From Date" => "Desde la fecha",
"From Time" => "Desde la hora",
"To Date" => "Hasta la fecha",
"To Time" => "Hasta la hora",
"The event ends before it starts" => "El evento termina antes de comiezar",
"There was a database fail" => "Se ha producido un error en la base de datos",
"Birthday" => "Cumpleaños",
"Business" => "Negocios",
"Call" => "Llamada",
"Clients" => "Clientes",
"Deliverer" => "Despachante",
"Holidays" => "Feriados",
"Ideas" => "Ideas",
"Journey" => "Viaje",
"Jubilee" => "Aniversario",
"Meeting" => "Reunión",
"Other" => "Otro",
"Personal" => "Personal",
"Projects" => "Proyectos",
"Questions" => "Preguntas",
"Work" => "Trabajo",
"by" => "por",
"unnamed" => "sin nombre",
"You do not have the permissions to update this calendar." => "No tenés permisos suficientes para actualizar este calendario.",
"You do not have the permissions to delete this calendar." => "No tenés permisos suficientes para eliminar este calendario.",
"You do not have the permissions to add to this calendar." => "No tenés permisos suficientes para añadir a este calendario.",
"You do not have the permissions to add events to this calendar." => "No tenés permisos suficientes para añadir eventos a este calendario.",
"You cannot add non-public events to a shared calendar." => "No se puede agregar un evento no-público a un calendario compartido.",
"You do not have the permissions to delete this event." => "No tenés permisos suficientes para eliminar este evento.",
"Busy" => "Ocupado",
"Show full event" => "Mostrar evento completo",
"Show only busy" => "Mostrar ocupados unicamente",
"Hide event" => "Ocultar evento",
"Does not repeat" => "No se repite",
"Daily" => "Diariamente",
"Weekly" => "Semanalmente",
"Every Weekday" => "Días laborables",
"Bi-Weekly" => "Cada 2 semanas",
"Monthly" => "Mensualmente",
"Yearly" => "Anualmente",
"never" => "nunca",
"by occurrences" => "por ocurrencias",
"by date" => "por fecha",
"by monthday" => "por día del mes",
"by weekday" => "por día de la semana",
"events week of month" => "eventos de la semana dentro del mes",
"first" => "primer",
"second" => "segundo",
"third" => "tercer",
"fourth" => "cuarto",
"fifth" => "quinto",
"last" => "último",
"by events date" => "por fecha de los eventos",
"by yearday(s)" => "por día(s) del año",
"by weeknumber(s)" => "por número(s) de semana",
"by day and month" => "por día y mes",
"Contact birthdays" => "Cumpleaños",
"Date" => "Fecha",
"Cal." => "Cal.",
"Day" => "Día",
"Week" => "Semana",
"Month" => "Mes",
"Today" => "Hoy",
"CalDav Link" => "Enlace a CalDav",
"Timezone" => "Zona horaria",
"Update timezone automatically" => "Actualizar zona horaria automáticamente",
"Time format" => "Formato de hora",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "La semana comienza el",
"Cache" => "Caché",
"Clear cache for repeating events" => "Limpiar caché de eventos recurrentes",
"Primary CalDAV address" => "Dirección primaria CalDAV",
"iOS/OS X CalDAV address" => "Dirección iOS/OS X CalDAV",
"Share Calendar" => "Compartir calendario",
"Download" => "Descargar",
"Edit" => "Editar",
"Delete" => "Borrar",
"New calendar" => "Calendario nuevo",
"Edit calendar" => "Editar calendario",
"Edit event" => "Editar evento",
"Save event" => "Guardar evento",
"Delete event" => "Borrar evento",
"Eventinfo" => "Información del evento",
"Repeating" => "Repetición",
"Alarm" => "Alarma",
"Attendees" => "Asistentes",
"Share" => "Compartir",
"Title of the Event" => "Título del evento",
"from" => "de",
"to" => "a",
"All Day Event" => "Todo el día",
"Advanced options" => "Opciones avanzadas",
"Location" => "Lugar",
"Categories (separate by comma)" => "Categorías (separar usando comas)",
"Edit categories" => "Editar categorías",
"Description" => "Descripción",
"Export event" => "Exportar evento",
"Repeat" => "Repetir",
"Advanced" => "Avanzado",
"Select weekdays" => "Seleccionar días de la semana",
"Select days" => "Seleccionar días",
"and the events day of year." => "y el día del año de los eventos.",
"and the events day of month." => "y el día del mes de los eventos.",
"Select months" => "Seleccionar meses",
"Select weeks" => "Seleccionar semanas",
"and the events week of year." => "y la semana del año de los eventos.",
"Interval" => "Intervalo",
"End" => "Fin",
"occurrences" => "ocurrencias:",
"Visibility to people shared with" => "Visibilidad de las personas con las que comparto",
"create a new calendar" => "Crear un nuevo calendario",
"Import a calendar file" => "Importar un archivo de calendario",
"Please choose a calendar" => "Elegí un calendario",
"Name of new calendar" => "Nombre del nuevo calendario",
"Take an available name!" => "¡Elegí un nombre que esté disponible!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Ya existe un calendario con este nombre. Si seguís, se combinarán los calendarios.",
"Remove all events from the selected calendar" => "Remover todos los eventos del calendario seleccionado ",
"Import" => "Importar",
"Close Dialog" => "Cerrar diálogo",
"Create a new event" => "Crear un evento nuevo",
"Create event" => "Crear evento",
"Share with user or group" => "Compartir con usuario o grupo",
"Unshare" => "Dejar de compartir",
"Not shared with anyone" => "No está compartido con nadie",
"Send Email" => "Mandar correo electrónico",
"Shared via calendar" => "Compartido a través del calendario",
"Not shared with anyone via calendar" => "No está compartido con nadie vía calendario",
"View an event" => "Ver un evento",
"Category" => "Categoría",
"No categories selected" => "No hay categorías seleccionada",
"%s of %s" => "%s de %s",
"Access Class" => "Clase de acceso",
"From" => "Desde",
"at" => "a las",
"To" => "Hasta"
);
